function [Cov] = HACpan_siv(N,Data,errors)
%HAC_siv calculate heteroskedasticity and autocorrlation robust covariance-variance of two
%panel equations with same data as independent variables 
%Approach follows Daniel Hoechele https://doi.org/10.1177/1536867X0700700301
%N=size cross section, Data=explaining variables, errors=errors


maxLag = floor((4*(size(Data,1))/100)^(2/9))+1; 
Cov=zeros((size(Data,2))*2); 

for i=1:2
    for t=1:1:size(Data)/N
        ht(t,:,i)=nansum(Data(t:size(Data)/N:size(Data,1),:).*errors(t:size(Data)/N:size(Data,1),i),1);
    end
end

Data(isnan(Data)) = 0;

for i=0:1 
    cov=zeros(size(Data,2),size(Data,2)); bla=zeros(size(Data,2),size(Data,2)); bla2=zeros(size(Data,2),size(Data,2));
 for j=1:size(errors,1)/N
      cov=cov+ht(j,:,i+1)'*ht(j,:,i+1); 
 end
 
 for v=1:maxLag
     for j=v+1:size(errors,1)/N
         bla2=(ht(j,:,i+1)'*ht(j-v,:,i+1)+ht(j,:,i+1)'*ht(j-v,:,i+1))'+bla2;
     end
     bla=(1-(v/(1+maxLag)))*bla2+bla;
     bla2=zeros(size(Data,2),size(Data,2));
 end
 cov=cov+bla;
 Cov(i*(size(Data,2))+1:(i+1)*(size(Data,2)),i*(size(Data,2))+1:(i+1)*(size(Data,2)))=((Data'*Data)^-1)*cov*((Data'*Data)^-1);
 
end

cov=zeros(size(Data,2),size(Data,2)); bla=zeros(size(Data,2),size(Data,2)); bla2=zeros(size(Data,2),size(Data,2));
 for j=1:size(errors,1)/N
        cov=cov+ht(j,:,1)'*ht(j,:,2); 
 end
 for v=1:maxLag
     for j=v+1:size(errors,1)/N
         bla2=(ht(j,:,1)'*ht(j-v,:,2)+ht(j-v,:,1)'*ht(j,:,2))+bla2;
     end
     bla=(1-(v/(1+maxLag)))*bla2+bla;
     bla2=zeros(size(Data,2),size(Data,2));
 end
 cov=cov+bla;
     
        cov=((Data'*Data)^-1)*cov*((Data'*Data)^-1);
        Cov(size(Data,2)+1:end,1:size(Data,2))=cov;
        Cov(1:size(Data,2),size(Data,2)+1:end)=cov;
        